@@ -12,8 +12,7 @@
 #' ds$petloc <- addSubvariables(ds$petloc, ds[c("petloc_school", "petloc_daycare")])
 #' }
 #' @export
-addSubvariable <- function (variable, subvariable) {
-
+addSubvariable <- function(variable, subvariable) {
     new.urls <- addSubvarDef(variable, subvariable)
 
     ## Store these for post workaround
@@ -21,11 +20,13 @@ addSubvariable <- function (variable, subvariable) {
 
     ## Do the adding
     crPATCH(shojiURL(variable, "catalogs", "subvariables"),
-        body=toJSON(sapply(new.urls, emptyObject, simplify=FALSE)))
+        body = toJSON(sapply(new.urls, emptyObject, simplify = FALSE))
+    )
 
     ## Workaround because apparently bind/rebind isn't retaining the order
     crPATCH(self(variable),
-        body=toJSON(list(subvariables=I(c(subvar.urls, new.urls)))))
+        body = toJSON(list(subvariables = I(c(subvar.urls, new.urls))))
+    )
 
     ## Refresh and return
     dropCache(datasetReference(variable))
@@ -36,27 +37,30 @@ addSubvariable <- function (variable, subvariable) {
 #' @export
 addSubvariables <- addSubvariable
 
-addSubvarDef <- function (var, subvar) {
+addSubvarDef <- function(var, subvar) {
     ## Input can be a variable, subvariable, dataset subset or
     ## a mixed or uniform list of variables and subvariables this
     ## wraps single entries in a list for type consistency.
     if (inherits(subvar, "VariableDefinition") ||
-            is.variable(subvar)) {
+        is.variable(subvar)) {
         ## wrap single variables in list
         subvar <- list(subvar)
     }
 
-    vardefs <- vapply(subvar,
+    vardefs <- vapply(
+        subvar,
         function(x) inherits(x, "VariableDefinition"),
-        logical(1))
+        logical(1)
+    )
 
     out <- vector("list", length(subvar))
 
     if (any(vardefs)) {
         ds <- loadDataset(datasetReference(var))
         var_cat_url <- shojiURL(ds, "catalogs", "variables")
-        new_var_urls <- lapply(subvar[vardefs],
-            function (x) try(POSTNewVariable(var_cat_url, x), silent = TRUE)
+        new_var_urls <- lapply(
+            subvar[vardefs],
+            function(x) try(POSTNewVariable(var_cat_url, x), silent = TRUE)
         )
         checkVarDefErrors(new_var_urls)
         out[vardefs] <- new_var_urls
@@ -65,4 +69,4 @@ addSubvarDef <- function (var, subvar) {
         out[!vardefs] <- urls(subvar[!vardefs])
     }
     return(as.character(out))
-}
\ No newline at end of file
+}
