@@ -1,12 +1,12 @@
 #' Kill the active Crunch session
 #' @export
 #' @importFrom httpcache clearCache
-logout <- function () {
-    try(crGET(rootURL("logout")), silent=TRUE)
+logout <- function() {
+    try(crGET(rootURL("logout")), silent = TRUE)
     clearCache()
     old.prompt <- getOption("crunch.old.prompt")
     if (!is.null(old.prompt)) {
-        options(prompt=old.prompt, crunch.old.prompt=NULL)
+        options(prompt = old.prompt, crunch.old.prompt = NULL)
     }
 }
 
@@ -34,18 +34,17 @@ logout <- function () {
 #' @param ... additional parameters passed in the authentication. Not
 #' currently supported by the Crunch API.
 #' @export
-login <- function (email=envOrOption("crunch.email"),
-                   password=envOrOption("crunch.pw"), ...) {
-
+login <- function(email = envOrOption("crunch.email"),
+                  password = envOrOption("crunch.pw"), ...) {
     old.prompt <- getOption("crunch.old.prompt")
     if (!is.null(old.prompt)) {
         ## We may already be logged in. Log out first.
         logout()
     }
-    auth <- crunchAuth(email=email, password=password, ...)
+    auth <- crunchAuth(email = email, password = password, ...)
     options(
-        prompt=paste("[crunch]", getOption("prompt")),
-        crunch.old.prompt=getOption("prompt")
+        prompt = paste("[crunch]", getOption("prompt")),
+        crunch.old.prompt = getOption("prompt")
     )
     message("Logged into crunch.io as ", email)
     ## Return a Session object
@@ -61,10 +60,10 @@ login <- function (email=envOrOption("crunch.email"),
 #' cr$projects
 #' }
 #' @export
-session <- function () new("Session")
+session <- function() new("Session")
 
 #' @importFrom utils installed.packages
-crunchAuth <- function (email, password=NULL, ...) {
+crunchAuth <- function(email, password = NULL, ...) {
     ## Validate authentication inputs and then POST to the API
     if (is.null(email)) {
         halt("Must supply the email address associated with your crunch.io account")
@@ -74,7 +73,6 @@ crunchAuth <- function (email, password=NULL, ...) {
             prompt <- paste0("Crunch.io password for ", email, ": ")
             if ("rstudioapi" %in% rownames(installed.packages()) &&
                 rstudioapi::hasFun("askForPassword")) {
-
                 password <- rstudioapi::askForPassword(prompt)
             } else {
                 cat(prompt)
@@ -86,20 +84,23 @@ crunchAuth <- function (email, password=NULL, ...) {
     }
 
     crPOST(absoluteURL("public/login/", getOption("crunch.api")),
-        body=toJSON(list(email=email, password=password, ...)),
-        status.handlers=list(`401`=function (response, user=email) {
+        body = toJSON(list(email = email, password = password, ...)),
+        status.handlers = list(`401` = function(response, user = email) {
             halt(paste("Unable to authenticate", user))
-        }))
+        })
+    )
 }
 
-without_echo <- function (expr) {
+without_echo <- function(expr) {
     if (.Platform$OS.type == "unix") {
         ## Don't print the password being typed
-        try(system("stty -echo", ignore.stdout=TRUE, ignore.stderr=TRUE),
-            silent=TRUE)
+        try(system("stty -echo", ignore.stdout = TRUE, ignore.stderr = TRUE),
+            silent = TRUE
+        )
         on.exit({
-            try(system("stty echo", ignore.stdout=TRUE, ignore.stderr=TRUE),
-                silent=TRUE)
+            try(system("stty echo", ignore.stdout = TRUE, ignore.stderr = TRUE),
+                silent = TRUE
+            )
             cat("\n")
         })
     }
@@ -107,7 +108,7 @@ without_echo <- function (expr) {
 }
 
 ## Pass through for test mocking
-read_input <- function (...) readline(...)
+read_input <- function(...) readline(...)
 
 #' Add an auth token as a cookie manually
 #'
@@ -119,13 +120,14 @@ read_input <- function (...) readline(...)
 #' @export
 #' @keywords internal
 #' @importFrom httr set_cookies
-tokenAuth <- function (token, ua="token") {
+tokenAuth <- function(token, ua = "token") {
     set_crunch_config(
         c(
-            set_cookies(token=token),
-            add_headers(`user-agent`=crunchUserAgent(ua))
+            set_cookies(token = token),
+            add_headers(`user-agent` = crunchUserAgent(ua))
         ),
-        update=TRUE)
+        update = TRUE
+    )
 }
 
-jupyterLogin <- function (token) tokenAuth(token, ua="jupyter.crunch.io")
+jupyterLogin <- function(token) tokenAuth(token, ua = "jupyter.crunch.io")
