@@ -1,35 +1,29 @@
-cubeDims <- function (cube) {
+cubeDims <- function(cube) {
     ## This function wraps up all of the quirks of the Crunch cube API and
     ## standardizes the various ways that metadata about the dimensions is
     ## represented in it.
 
     ## First, grab the row/col/etc. labels from the cube
-    dimnames <- lapply(cube$result$dimensions, function (a) {
+    dimnames <- lapply(cube$result$dimensions, function(a) {
         ## Collect the variable metadata about the dimensions
         tuple <- cubeVarReferences(a)
-        if (tuple$type == "boolean") {
-            ## TODO: delete this when boolean support is removed
-            return(list(
-                name=c("FALSE", "TRUE"),
-                missing=c(FALSE, FALSE),
-                references=tuple
-            ))
-        }
         ## If enumerated, will be "elements", not "categories"
         d <- tuple$categories %||% a$type$elements
         return(list(
-            name=vapply(d, elementName, character(1)),
-            missing=vapply(d, function (el) isTRUE(el$missing), logical(1)),
-            references=tuple
+            name = vapply(d, elementName, character(1)),
+            missing = vapply(d, function(el) isTRUE(el$missing), logical(1)),
+            references = tuple
         ))
     })
-    names(dimnames) <- vapply(dimnames, function (x) x$references$alias,
-        character(1))
+    names(dimnames) <- vapply(
+        dimnames, function(x) x$references$alias,
+        character(1)
+    )
 
     return(CubeDims(dimnames))
 }
 
-cubeVarReferences <- function (x) {
+cubeVarReferences <- function(x) {
     ## Extract ZZ9-ish metadata from a cube dimension or measure and return
     ## in a way that looks like what comes in a variable catalog
     tuple <- x$references
@@ -40,9 +34,11 @@ cubeVarReferences <- function (x) {
 
     if (!is.null(tuple$subreferences)) {
         # Inject subreference names into the tuple if they exist.
-        tuple$subvariables <- vapply(tuple$subreferences,
-                                     function (x) x$alias %||% "",
-                                     character(1))
+        tuple$subvariables <- vapply(
+            tuple$subreferences,
+            function(x) x$alias %||% "",
+            character(1)
+        )
 
         if (is.null(names(tuple$subreferences))) {
             # if there are no names for the subvariable elements, fake urls from
@@ -56,7 +52,7 @@ cubeVarReferences <- function (x) {
 
     tuple$categories <- x$type$categories
     ## Sniff for 3VL
-    if (!is.null(tuple$categories) && is.3vl(Categories(data=tuple$categories))) {
+    if (!is.null(tuple$categories) && is.3vl(Categories(data = tuple$categories))) {
         ## Make this look like an R logical does when it is tabulated
         tuple$categories[[1]]$name <- "TRUE"
         tuple$categories[[2]]$name <- "FALSE"
@@ -67,7 +63,7 @@ cubeVarReferences <- function (x) {
     return(tuple)
 }
 
-elementName <- function (el) {
+elementName <- function(el) {
     ## Given a category or element in a cube dim, what's its name?
     out <- el$value
     if (is.null(out)) {
@@ -76,7 +72,7 @@ elementName <- function (el) {
     } else if (is.list(out)) {
         if (length(out) == 2 && is.null(names(out))) {
             ## el$value is bin boundaries, as in a binned numeric.
-            out <- paste(unlist(out), collapse="-")
+            out <- paste(unlist(out), collapse = "-")
         } else {
             ## This is probably a subvariable. Look for its name.
             out <- out$references$name
@@ -108,22 +104,24 @@ NULL
 
 #' @rdname cube-methods
 #' @export
-setMethod("dimnames", "CubeDims", function (x) {
-    lapply(x, function (a) a$name)
+setMethod("dimnames", "CubeDims", function(x) {
+    lapply(x, function(a) a$name)
 })
 
 #' @rdname cube-methods
 #' @export
-setMethod("dim", "CubeDims",
-    function (x) vapply(dimnames(x), length, integer(1), USE.NAMES=FALSE))
+setMethod(
+    "dim", "CubeDims",
+    function(x) vapply(dimnames(x), length, integer(1), USE.NAMES = FALSE)
+)
 
 #' @rdname cube-methods
 #' @export
-setMethod("is.na", "CubeDims", function (x) lapply(x, function (a) a$missing))
+setMethod("is.na", "CubeDims", function(x) lapply(x, function(a) a$missing))
 
 #' @rdname cube-methods
 #' @export
-setMethod("dimensions", "CrunchCube", function (x) {
+setMethod("dimensions", "CrunchCube", function(x) {
     dims <- x@dims
     selecteds <- is.selectedDimension(dims)
     return(dims[!selecteds])
@@ -131,7 +129,7 @@ setMethod("dimensions", "CrunchCube", function (x) {
 
 #' @rdname cube-methods
 #' @export
-setMethod("dimensions<-", c("CrunchCube", "CubeDims"), function (x, value) {
+setMethod("dimensions<-", c("CrunchCube", "CubeDims"), function(x, value) {
     dims <- x@dims
     selecteds <- is.selectedDimension(dims)
     x@dims[!selecteds] <- value
@@ -140,11 +138,11 @@ setMethod("dimensions<-", c("CrunchCube", "CubeDims"), function (x, value) {
 
 #' @rdname cube-methods
 #' @export
-setMethod("[", "CubeDims", function (x, i, ...) {
-    return(CubeDims(x@.Data[i], names=x@names[i]))
+setMethod("[", "CubeDims", function(x, i, ...) {
+    return(CubeDims(x@.Data[i], names = x@names[i]))
 })
 
-is.selectedDimension <- function (dims) getDimTypes(dims) == "mr_selections"
+is.selectedDimension <- function(dims) getDimTypes(dims) == "mr_selections"
 
 #' Get dimension type
 #'
@@ -163,14 +161,14 @@ is.selectedDimension <- function (dims) getDimTypes(dims) == "mr_selections"
 #' the array variable types are more specific.
 #' @export
 #' @keywords internal
-getDimTypes <-  function (x) {
+getDimTypes <- function(x) {
     if (inherits(x, "CrunchCube")) {
         x <- x@dims
     }
 
-    what_dim_is_it <- function (one_var, array_aliases) {
+    what_dim_is_it <- function(one_var, array_aliases) {
         dim_type <- type(one_var)
-        
+
         if (alias(one_var) %in% array_aliases) {
             # we are in an array, we need to figure out if this is a multiple
             # response or not
@@ -182,14 +180,14 @@ getDimTypes <-  function (x) {
             if (length(array_cat_dim) < 1) {
                 return(dim_type)
             }
-            
+
             # if this is a variable crossed by itself, then array_cat_dim will
             # actually have two copies of the categories dimension. We take the
             # first one becasue it should be identical to all the others. If it
-            # isn't this might produce weird results. 
+            # isn't this might produce weird results.
             # TODO: Investigate checking by ID
             array_cats <- categories(array_cat_dim[[1]])
-            
+
             # if we meet these conditions, we are actually a multiple response
             # and should label ourself as such.
             # Unlike the strict is.3vl, this doesn't compare cat names because
@@ -198,7 +196,7 @@ getDimTypes <-  function (x) {
                 setequal(ids(array_cats), c(-1, 0, 1)) &&
                 sum(is.selected(array_cats)) == 1 &&
                 sum(is.na(array_cats)) == 1
-            
+
             if (is.MR) {
                 # MRs have mr_items or mr_selections
                 if (dim_type == "subvariable_items") {
@@ -215,12 +213,12 @@ getDimTypes <-  function (x) {
                 }
             }
         }
-        
+
         return(dim_type)
     }
-  
+
     vars <- variables(x)
-    array_aliases <- aliases(vars)[types(vars) == "subvariable_items"]  
+    array_aliases <- aliases(vars)[types(vars) == "subvariable_items"]
     out <- vapply(vars, what_dim_is_it, character(1), array_aliases)
 
     names(out) <- names(vars)
