@@ -24,10 +24,10 @@
 #' # The assignment method lets you move a dataset to a project
 #' datasets(proj) <- ds
 #' }
-datasets <- function (x=getAPIRoot()) {
+datasets <- function(x = getAPIRoot()) {
     if (inherits(x, "SearchResults")) {
         ## This is close enough to a dataset catalog
-        out <- structure(list(index=x$datasets), class="shoji")
+        out <- structure(list(index = x$datasets), class = "shoji")
     } else {
         out <- crGET(shojiURL(x, "catalogs", "datasets"))
     }
@@ -53,8 +53,8 @@ datasets <- function (x=getAPIRoot()) {
 #' @return Character vector of dataset names, each of which would be a valid
 #' input for [loadDataset()]
 #' @export
-listDatasets <- function (kind=c("active", "all", "archived"), project=NULL,
-    refresh=FALSE, shiny = FALSE) {
+listDatasets <- function(kind = c("active", "all", "archived"), project = NULL,
+                         refresh = FALSE, shiny = FALSE) {
     if (shiny) {
         checkInstalledPackages(c("rstudioapi", "shiny", "miniUI"))
         rstudioapi::verifyAvailable("0.99.878")
@@ -65,8 +65,8 @@ listDatasets <- function (kind=c("active", "all", "archived"), project=NULL,
     }
 }
 
-selectDatasetCatalog <- function (kind=c("active", "all", "archived"),
-                                  project=NULL, refresh=FALSE) {
+selectDatasetCatalog <- function(kind = c("active", "all", "archived"),
+                                 project = NULL, refresh = FALSE) {
     Call <- match.call()
     if (is.null(project)) {
         ## Default: we'll get the dataset catalog from the API root
@@ -77,8 +77,10 @@ selectDatasetCatalog <- function (kind=c("active", "all", "archived"),
     }
     if (is.null(project)) {
         ## Means a project was specified (like by name) but it didn't exist
-        halt("Project ", deparseAndFlatten(eval.parent(Call$project)),
-            " is not valid")
+        halt(
+            "Project ", deparseAndFlatten(eval.parent(Call$project)),
+            " is not valid"
+        )
     }
 
     if (refresh) {
@@ -90,9 +92,10 @@ selectDatasetCatalog <- function (kind=c("active", "all", "archived"),
 
     ## Subset as indicated
     return(switch(match.arg(kind),
-        active=active(catalog),
-        all=catalog,
-        archived=archived(catalog)))
+        active = active(catalog),
+        all = catalog,
+        archived = archived(catalog)
+    ))
 }
 
 #' Refresh the local list of Crunch datasets
@@ -102,7 +105,7 @@ selectDatasetCatalog <- function (kind=c("active", "all", "archived"),
 #' @export
 #' @importFrom httpcache dropOnly
 #' @keywords internal
-updateDatasetList <- function () {
+updateDatasetList <- function() {
     warning("updateDatasetList is being deprecated.")
     dropOnly(sessionURL("datasets"))
 }
@@ -127,7 +130,7 @@ updateDatasetList <- function () {
 #' ds <- loadDatasets(dsName)
 #' }
 #' @export
-loadDataset <- function (dataset, kind=c("active", "all", "archived"), project=NULL, refresh=FALSE) {
+loadDataset <- function(dataset, kind = c("active", "all", "archived"), project = NULL, refresh = FALSE) {
     if (is.character(dataset) && startsWith(dataset, "http")) {
         ## Check to see if this is a URL, in which case, GET it
         if (!grepl("/api/", dataset)) {
@@ -136,6 +139,15 @@ loadDataset <- function (dataset, kind=c("active", "all", "archived"), project=N
         }
         return(loadDatasetFromURL(dataset))
     } else if (!inherits(dataset, "DatasetTuple")) {
+        if (missing(project) && is.character(dataset)) {
+            ## See if "dataset" is a path
+            dataset <- parseFolderPath(dataset)
+            if (length(dataset) > 1) {
+                ## Walk the path
+                ds_url <- datasetURLFromPath(dataset)
+                return(loadDatasetFromURL(ds_url))
+            } # else, proceed normally
+        }
         dscat <- selectDatasetCatalog(kind, project, refresh)
         dsname <- dataset
         dataset <- dscat[[dataset]]
@@ -146,17 +158,14 @@ loadDataset <- function (dataset, kind=c("active", "all", "archived"), project=N
     return(entity(dataset))
 }
 
-loadDatasetFromURL <- function (url) {
+loadDatasetFromURL <- function(url) {
     ## Load dataset without touching a dataset catalog
     dataset <- CrunchDataset(crGET(url))
-    if (isTRUE(getOption("crunch.variable.folders", FALSE))) {
-        ## Call getRootFolderURL(), which will turn on folders and bust cache as needed
-        getRootFolderURL(dataset)
-        dataset <- CrunchDataset(crGET(url))
-    }
-    tuple(dataset) <- DatasetTuple(entity_url=self(dataset),
-        body=dataset@body,
-        index_url=shojiURL(dataset, "catalogs", "parent"))
+    tuple(dataset) <- DatasetTuple(
+        entity_url = self(dataset),
+        body = dataset@body,
+        index_url = shojiURL(dataset, "catalogs", "parent")
+    )
     return(dataset)
 }
 
@@ -178,7 +187,7 @@ loadDatasetFromURL <- function (url) {
 #' @return (Invisibly) the API response from deleting the dataset
 #' @seealso [delete]
 #' @export
-deleteDataset <- function (x, ...) {
+deleteDataset <- function(x, ...) {
     if (!is.dataset(x)) {
         if (is.numeric(x)) {
             x <- listDatasets()[x]
